"use strict";

var Promise = require("bluebird");

/* exported logger */
var logger = require('../../logger');

var AbstractDbPanel = require('./AbstractDbPanel');
var PanelControlElementType = require('../PanelControlElementType');

function MiRnaPanel(params) {
  params.panelName = "mirna";
  params.helpTip = '<p>source: <a target="_mirtarbase" href="http://mirtarbase.mbc.nctu.edu.tw/">miRTarBase</a></p>'
      + '<p>use only mature sequence IDs according to <a target="_mirbase" href="http://www.mirbase.org">www.mirbase.org</a> (e.g., hsa-miR-125a-3p)</p>'
      + '<p>only targets with strong evidence as defined by miRTarBase are displayed<p>separate multiple search by semicolon</p>';
  params.placeholder = "mature seq. ID (miRTarBase)";
  AbstractDbPanel.call(this, params);
}
MiRnaPanel.prototype = Object.create(AbstractDbPanel.prototype);
MiRnaPanel.prototype.constructor = MiRnaPanel;

MiRnaPanel.prototype.createPreamble = function(miRna) {
  var self = this;
  var guiUtils = self.getGuiUtils();
  var result = document.createElement("div");
  if (miRna === undefined || miRna.getName() === undefined) {
    result.appendChild(guiUtils.createLabel("NOT FOUND"));
  } else {
    var line = document.createElement("div");
    line.appendChild(guiUtils.createLabel("&mu;Rna: "));
    line.appendChild(guiUtils.createLink("http://www.mirbase.org/cgi-bin/mirna_entry.pl?acc=" + miRna.getName(), miRna
        .getName()));
    line.appendChild(guiUtils.createNewLine());

    result.appendChild(line);
    result.appendChild(guiUtils.createNewLine());
  }

  return result;
};

MiRnaPanel.prototype.createTableElement = function(target, icon) {
  return this.createTargetRow(target, icon);
};

MiRnaPanel.prototype.searchByQuery = function() {
  var self = this;
  var query = self.getControlElement(PanelControlElementType.SEARCH_INPUT).value;
  return self.getOverlayDb().searchByQuery(query);
};

MiRnaPanel.prototype.init = function() {
  var query = ServerConnector.getSessionData().getMiRnaQuery();
  if (query !== undefined) {
    return this.getOverlayDb().searchByEncodedQuery(query);
  } else {
    return Promise.resolve();
  }
};

module.exports = MiRnaPanel;
