"use strict";

/* exported logger */

var ObjectWithListeners = require('../../ObjectWithListeners');

var Annotation = require("./Annotation");
var Model = require('./MapModel');

var logger = require('../../logger');

function Project(data) {
  // call super constructor
  ObjectWithListeners.call(this);
  this.registerListenerType("onreload");

  if (data !== undefined) {
    this.loadFromData(data);
  }
}

// this class inherits from ObjectWithListeners class where generic methods for
// listeners are set
Project.prototype = Object.create(ObjectWithListeners.prototype);
Project.prototype.constructor = Project;

Project.prototype.loadFromData = function(data) {
  var self = this;
  if (typeof data === "string") {
    // replace is due to some strange problem with serialization
    data = JSON.parse(data.replace(/\n/g, " "));
  }
  if (data instanceof Project) {
    self.update(data);

  } else {
    self.setId(parseInt(data.idObject));
    self.setProjectId(data.projectId);
    self.setVersion(data.version);
    self.setName(data.name);
    self.setOverviewImages(data.overviewImageViews);
    self.setTopOverviewImage(data.topOverviewImage);
    self.setDisease(data.disease);
    self.setOrganism(data.organism);
    self.setStatus(data.status);
    self.setNotifyEmail(data.notifyEmail);
    self.setProgress(data.progress);

    self.callListeners("onreload");
  }
};

Project.prototype.update = function(data) {
  var self = this;
  self.setId(data.getId());
  self.setProjectId(data.getProjectId());
  self.setVersion(data.getVersion());
  self.setName(data.getName());
  self.setOverviewImages(data.getOverviewImages());
  self.setTopOverviewImage(data.getTopOverviewImage());
  self.setDisease(data.getDisease());
  self.setOrganism(data.getOrganism());
  self.setStatus(data.getStatus());
  self.setProgress(data.getProgress());
  self.setNotifyEmail(data.getNotifyEmail());

  if (data.getModel() !== undefined) {
    self.setModel(new Model(data.getModel()));
  }

  self.callListeners("onreload");
};

Project.prototype.getId = function() {
  return this._id;
};

Project.prototype.setId = function(id) {
  this._id = parseInt(id);
};

Project.prototype.getProjectId = function() {
  return this._projectId;
};

Project.prototype.setProjectId = function(projectId) {
  this._projectId = projectId;
};

Project.prototype.getVersion = function() {
  return this._version;
};

Project.prototype.setVersion = function(version) {
  this._version = version;
};

Project.prototype.getName = function() {
  return this._name;
};
Project.prototype.setName = function(name) {
  this._name = name;
};
Project.prototype.getModel = function() {
  return this._model;
};
Project.prototype.setModel = function(model) {
  this._model = model;
};

Project.prototype.getOverviewImages = function() {
  return this._overviewImages;
};
Project.prototype.setOverviewImages = function(overviewImages) {
  this._overviewImages = overviewImages;
};

Project.prototype.getTopOverviewImage = function() {
  return this._topOverviewImage;
};
Project.prototype.setTopOverviewImage = function(topOverviewImage) {
  this._topOverviewImage = topOverviewImage;
};

Project.prototype.getDisease = function() {
  return this._disease;
};
Project.prototype.setDisease = function(disease) {
  if (disease !== undefined && disease !== null) {
    this._disease = new Annotation(disease);
  } else {
    this._disease = undefined;
  }
};

Project.prototype.getOrganism = function() {
  return this._organism;
};
Project.prototype.setOrganism = function(organism) {
  if (organism !== undefined && organism !== null) {
    this._organism = new Annotation(organism);
  } else {
    this._organism = undefined;
  }
};

Project.prototype.getStatus = function() {
  return this._status;
};
Project.prototype.setStatus = function(status) {
  this._status = status;
};

Project.prototype.getProgress = function() {
  return this._progress;
};
Project.prototype.setProgress = function(progress) {
  this._progress = progress;
};

Project.prototype.getNotifyEmail = function() {
  return this._notifyEmail;
};
Project.prototype.setNotifyEmail = function(notifyEmail) {
  this._notifyEmail = notifyEmail;
};

module.exports = Project;
