"use strict";

/* exported logger */

require('../../mocha-config.js');

var LeftPanel = require('../../../../main/js/gui/leftPanel/LeftPanel');
var IdentifiedElement = require('../../../../main/js/map/data/IdentifiedElement');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('LeftPanel', function() {

  it('constructor', function() {
    var map = helper.createCustomMap();
    helper.createSearchDbOverlay(map);
    helper.createDrugDbOverlay(map);
    helper.createChemicalDbOverlay(map);
    helper.createMiRnaDbOverlay(map);

    new LeftPanel({
      element : testDiv,
      customMap : map
    });

    assert.equal(logger.getWarnings().length, 0);

  });

  describe('prepareElementDetailsContent', function() {
    it('for element', function() {
      var map;
      var panel;
      return ServerConnector.getProject().then(function(project) {
        map = helper.createCustomMap(project);

        helper.createSearchDbOverlay(map);
        helper.createDrugDbOverlay(map);
        helper.createChemicalDbOverlay(map);
        helper.createMiRnaDbOverlay(map);

        panel = new LeftPanel({
          element : testDiv,
          customMap : map
        });

        var element = new IdentifiedElement({
          id : 329163,
          type : "ALIAS",
          modelId : map.getId()
        });
        return map.getModel().getByIdentifiedElement(element, true);
      }).then(function(alias) {
        var div = panel.prepareElementDetailsContent(alias);
        assert.ok(div);
      });
    });
    it('for point', function() {
      var map;
      var panel;
      return ServerConnector.getProject().then(function(project) {
        map = helper.createCustomMap(project);

        helper.createSearchDbOverlay(map);
        helper.createDrugDbOverlay(map);
        helper.createChemicalDbOverlay(map);
        helper.createMiRnaDbOverlay(map);

        panel = new LeftPanel({
          element : testDiv,
          customMap : map
        });

        var element = new IdentifiedElement({
          id : "(1.00,2.00)",
          type : "POINT",
          modelId : map.getId()
        });
        return map.getModel().getByIdentifiedElement(element, true);
      }).then(function(point) {
        var div = panel.prepareElementDetailsContent(point);
        assert.ok(div);
      });
    });
  });

});
