"use strict";

require('../../mocha-config.js');

var ProjectInfoPanel = require('../../../../main/js/gui/leftPanel/ProjectInfoPanel');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('ProjectInfoPanel', function() {

  it('contructor', function() {
    var div = testDiv;

    var map = helper.createCustomMap();

    new ProjectInfoPanel({
      element : div,
      customMap : map
    });
    assert.equal(logger.getWarnings().length, 0);
  });

  it('refresh', function() {
    var div = testDiv;
    var panel = new ProjectInfoPanel({
      element : div,
      customMap : helper.createCustomMap(),
    });
    return panel.refresh().then(function() {
      assert.ok(div.innerHTML.indexOf("UNKNOWN DISEASE MAP") >= 0);
    });
  });

  it('download source', function() {
    var div = testDiv;
    var panel = new ProjectInfoPanel({
      element : div,
      customMap : helper.createCustomMap(),
    });
    return panel.downloadSourceFile();
  });

  it('open manual', function() {
    var div = testDiv;
    new ProjectInfoPanel({
      element : div,
      customMap : helper.createCustomMap(),
    });
    return $("[name='manualLink']", $(div))[0].onclick();
  });

  it('show publication list', function() {
    return ServerConnector.getProject().then(function(project) {
      var div = testDiv;
      var panel = new ProjectInfoPanel({
        element : div,
        customMap : helper.createCustomMap(project),
      });
      return panel.showPublicationListDialog();
    });
  });

  it('show profile', function() {
    var map = helper.createCustomMap();

    var panel = new ProjectInfoPanel({
      element : testDiv,
      customMap : map
    });
    
    var user = helper.createUser();
    panel.showUserProfilePage(user);
  });

});
