"use strict";

/* exported logger */

var logger = require('../../logger');

var AliasMarker = require('../../../../main/js/map/marker/AliasMarker');
var IdentifiedElement = require('../../../../main/js/map/data/IdentifiedElement');
var assert = require('assert');

describe('AliasMarker', function() {

  it("Constructor", function() {
    var map;
    var alias, marker;
    return ServerConnector.getProject().then(function(project) {
      map = helper.createCustomMap(project);
      return map.getModel().getAliasById(329171);
    }).then(function(result) {
      alias = result;

      var identifiedElement = new IdentifiedElement(alias);
      identifiedElement.setIcon("empty.png");

      marker = new AliasMarker({
        element : identifiedElement,
        map : map
      });

      assert.equal(alias.getId(), marker.getId());
      assert.equal(map, marker.getCustomMap());
      assert.equal("empty.png", marker.getIcon());
      return marker.init();
    }).then(function() {
      assert.equal(alias, marker.getAliasData());
      assert.ok(marker._marker);
      assert.ok(marker.getBounds());
    });
  });

  it("click on marker", function() {
    var map;
    var marker;
    return ServerConnector.getProject().then(function(project) {
      map = helper.createCustomMap(project);
      return map.getModel().getAliasById(329171);
    }).then(function(alias) {

      var identifiedElement = new IdentifiedElement(alias);

      marker = new AliasMarker({
        element : identifiedElement,
        map : map
      });
      return marker.init();
    }).then(function() {
      return google.maps.event.trigger(marker.getGoogleMarker(), "click");
    });
  });

  it("click on marker when chemical is not available", function() {
    var projectId = "complex_model_with_submaps";
    helper.setUrl("http://test/?id=" + projectId);
    GuiConnector.getParams["id"] = projectId;
    var map;
    var marker;
    return ServerConnector.getProject(projectId).then(function(project) {
      map = helper.createCustomMap(project);
      var ov = helper.createChemicalDbOverlay(map);
      ov.setAllowGeneralSearch(false);
      ov.setAllowSearchById(false);
      return map.getModel().getAliasById(345334);
    }).then(function(alias) {
      var identifiedElement = new IdentifiedElement(alias);

      marker = new AliasMarker({
        element : identifiedElement,
        map : map
      });
      return marker.init();
    }).then(function() {

      return google.maps.event.trigger(marker.getGoogleMarker(), "click");
    });
  });

});
